@@ -1,4 +1,4 @@
-# Copyright (c) 2017-2018 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2017-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -80,8 +80,6 @@ def get_favicon_best_uri(favicons_path, uri):
     favicon_uri = None
     try:
         parsed = urlparse(uri)
-        if parsed.path == "/":
-            return None
         for uri in [parsed.netloc + parsed.path, parsed.netloc]:
             sql = sqlite3.connect(favicons_path, 600.0)
             result = sql.execute("SELECT url\
